@@ -30,12 +30,12 @@
 #include <iostream>
 #include <vector>
 
-#include <boost/algorithm/string.hpp>
 #include <boost/asio/ip/address.hpp>
 #include <boost/program_options.hpp>
 
 #include "check.h"
 // #include "jitter.h"
+#include "compressortype.h"
 #include "logger.h"
 #include "package-version.h"
 #include "ping.h"
@@ -222,7 +222,6 @@ int main(int argc, char** argv)
    unsigned int                       resultsTransactionLength;
    std::filesystem::path              resultsDirectory;
    std::string                        resultsCompressionString;
-   ResultsWriterCompressor            resultsCompression;
    unsigned int                       resultsFormatVersion;
    unsigned int                       resultsTimestampDepth;
 
@@ -230,6 +229,8 @@ int main(int argc, char** argv)
    commandLineOptions.add_options()
       ( "help,h",
            "Print help message" )
+      ( "version",
+           "Show program version" )
       ( "check",
            "Check environment" )
 
@@ -410,6 +411,10 @@ int main(int argc, char** argv)
                  << commandLineOptions;
        return 1;
    }
+   else if(vm.count("version")) {
+      std::cerr << "HiPerConTracer" << " " << HPCT_VERSION << "\n";
+      return 0;
+   }
    else if(vm.count("check")) {
       checkEnvironment("HiPerConTracer");
       return 0;
@@ -490,20 +495,9 @@ int main(int argc, char** argv)
       return 1;
    }
 #endif
-   boost::algorithm::to_upper(resultsCompressionString);
-   if(resultsCompressionString == "XZ") {
-      resultsCompression = ResultsWriterCompressor::XZ;
-   }
-   else if(resultsCompressionString == "BZIP2") {
-      resultsCompression = ResultsWriterCompressor::BZip2;
-   }
-   else if(resultsCompressionString == "GZIP") {
-      resultsCompression = ResultsWriterCompressor::GZip;
-   }
-   else if(resultsCompressionString == "NONE") {
-      resultsCompression = ResultsWriterCompressor::None;
-   }
-   else {
+   const CompressorType resultsCompression =
+      getCompressorTypeFromName(resultsCompressionString);
+   if(resultsCompression == CT_Invalid) {
       std::cerr << "ERROR: Invalid results compression: " << resultsCompressionString << "\n";
       return 1;
    }
@@ -664,7 +658,7 @@ int main(int argc, char** argv)
                ServiceSet.insert(service);
             }
             catch (std::exception& e) {
-               HPCT_LOG(fatal) << "Cannot create Jitter service - " << e.what();
+               HPCT_LOG(fatal) << "Cannot create Jitter service:" << e.what();
                return 1;
             }
          }
@@ -697,7 +691,7 @@ int main(int argc, char** argv)
                ServiceSet.insert(service);
             }
             catch (std::exception& e) {
-               HPCT_LOG(fatal) << "Cannot create Ping service - " << e.what();
+               HPCT_LOG(fatal) << "Cannot create Ping service:" << e.what();
                return 1;
             }
          }
@@ -729,7 +723,7 @@ int main(int argc, char** argv)
                ServiceSet.insert(service);
             }
             catch (std::exception& e) {
-               HPCT_LOG(fatal) << "Cannot create Traceroute service - " << e.what();
+               HPCT_LOG(fatal) << "Cannot create Traceroute service:" << e.what();
                return 1;
             }
          }
